# Change Log

## 0.0.2

* Disease, TrackerLog, Demographics Models added.
* Admin Site classes added for Django Admin.
* Readme documentation added.

## 0.0.1

* Initial code commit with structure and docs.
